# This file is auto-generated by the Perl DateTime Suite time zone
# code generator (0.08) This code generator comes with the
# DateTime::TimeZone module distribution in the tools/ directory

#
# Do not edit this file directly.

package DateTime::TimeZone::Catalog;

use strict;
use warnings;
use namespace::autoclean;

our $VERSION = '2.64';

our @ALL =
qw(
  Africa/Abidjan
  Africa/Algiers
  Africa/Bissau
  Africa/Cairo
  Africa/Casablanca
  Africa/Ceuta
  Africa/El_Aaiun
  Africa/Johannesburg
  Africa/Juba
  Africa/Khartoum
  Africa/Lagos
  Africa/Maputo
  Africa/Monrovia
  Africa/Nairobi
  Africa/Ndjamena
  Africa/Sao_Tome
  Africa/Tripoli
  Africa/Tunis
  Africa/Windhoek
  America/Adak
  America/Anchorage
  America/Araguaina
  America/Argentina/Buenos_Aires
  America/Argentina/Catamarca
  America/Argentina/Cordoba
  America/Argentina/Jujuy
  America/Argentina/La_Rioja
  America/Argentina/Mendoza
  America/Argentina/Rio_Gallegos
  America/Argentina/Salta
  America/Argentina/San_Juan
  America/Argentina/San_Luis
  America/Argentina/Tucuman
  America/Argentina/Ushuaia
  America/Asuncion
  America/Bahia
  America/Bahia_Banderas
  America/Barbados
  America/Belem
  America/Belize
  America/Boa_Vista
  America/Bogota
  America/Boise
  America/Cambridge_Bay
  America/Campo_Grande
  America/Cancun
  America/Caracas
  America/Cayenne
  America/Chicago
  America/Chihuahua
  America/Ciudad_Juarez
  America/Costa_Rica
  America/Cuiaba
  America/Danmarkshavn
  America/Dawson
  America/Dawson_Creek
  America/Denver
  America/Detroit
  America/Edmonton
  America/Eirunepe
  America/El_Salvador
  America/Fort_Nelson
  America/Fortaleza
  America/Glace_Bay
  America/Goose_Bay
  America/Grand_Turk
  America/Guatemala
  America/Guayaquil
  America/Guyana
  America/Halifax
  America/Havana
  America/Hermosillo
  America/Indiana/Indianapolis
  America/Indiana/Knox
  America/Indiana/Marengo
  America/Indiana/Petersburg
  America/Indiana/Tell_City
  America/Indiana/Vevay
  America/Indiana/Vincennes
  America/Indiana/Winamac
  America/Inuvik
  America/Iqaluit
  America/Jamaica
  America/Juneau
  America/Kentucky/Louisville
  America/Kentucky/Monticello
  America/La_Paz
  America/Lima
  America/Los_Angeles
  America/Maceio
  America/Managua
  America/Manaus
  America/Martinique
  America/Matamoros
  America/Mazatlan
  America/Menominee
  America/Merida
  America/Metlakatla
  America/Mexico_City
  America/Miquelon
  America/Moncton
  America/Monterrey
  America/Montevideo
  America/New_York
  America/Nome
  America/Noronha
  America/North_Dakota/Beulah
  America/North_Dakota/Center
  America/North_Dakota/New_Salem
  America/Nuuk
  America/Ojinaga
  America/Panama
  America/Paramaribo
  America/Phoenix
  America/Port-au-Prince
  America/Porto_Velho
  America/Puerto_Rico
  America/Punta_Arenas
  America/Rankin_Inlet
  America/Recife
  America/Regina
  America/Resolute
  America/Rio_Branco
  America/Santarem
  America/Santiago
  America/Santo_Domingo
  America/Sao_Paulo
  America/Scoresbysund
  America/Sitka
  America/St_Johns
  America/Swift_Current
  America/Tegucigalpa
  America/Thule
  America/Tijuana
  America/Toronto
  America/Vancouver
  America/Whitehorse
  America/Winnipeg
  America/Yakutat
  Antarctica/Casey
  Antarctica/Davis
  Antarctica/Macquarie
  Antarctica/Mawson
  Antarctica/Palmer
  Antarctica/Rothera
  Antarctica/Troll
  Antarctica/Vostok
  Asia/Almaty
  Asia/Amman
  Asia/Anadyr
  Asia/Aqtau
  Asia/Aqtobe
  Asia/Ashgabat
  Asia/Atyrau
  Asia/Baghdad
  Asia/Baku
  Asia/Bangkok
  Asia/Barnaul
  Asia/Beirut
  Asia/Bishkek
  Asia/Chita
  Asia/Colombo
  Asia/Damascus
  Asia/Dhaka
  Asia/Dili
  Asia/Dubai
  Asia/Dushanbe
  Asia/Famagusta
  Asia/Gaza
  Asia/Hebron
  Asia/Ho_Chi_Minh
  Asia/Hong_Kong
  Asia/Hovd
  Asia/Irkutsk
  Asia/Jakarta
  Asia/Jayapura
  Asia/Jerusalem
  Asia/Kabul
  Asia/Kamchatka
  Asia/Karachi
  Asia/Kathmandu
  Asia/Khandyga
  Asia/Kolkata
  Asia/Krasnoyarsk
  Asia/Kuching
  Asia/Macau
  Asia/Magadan
  Asia/Makassar
  Asia/Manila
  Asia/Nicosia
  Asia/Novokuznetsk
  Asia/Novosibirsk
  Asia/Omsk
  Asia/Oral
  Asia/Pontianak
  Asia/Pyongyang
  Asia/Qatar
  Asia/Qostanay
  Asia/Qyzylorda
  Asia/Riyadh
  Asia/Sakhalin
  Asia/Samarkand
  Asia/Seoul
  Asia/Shanghai
  Asia/Singapore
  Asia/Srednekolymsk
  Asia/Taipei
  Asia/Tashkent
  Asia/Tbilisi
  Asia/Tehran
  Asia/Thimphu
  Asia/Tokyo
  Asia/Tomsk
  Asia/Ulaanbaatar
  Asia/Urumqi
  Asia/Ust-Nera
  Asia/Vladivostok
  Asia/Yakutsk
  Asia/Yangon
  Asia/Yekaterinburg
  Asia/Yerevan
  Atlantic/Azores
  Atlantic/Bermuda
  Atlantic/Canary
  Atlantic/Cape_Verde
  Atlantic/Faroe
  Atlantic/Madeira
  Atlantic/South_Georgia
  Atlantic/Stanley
  Australia/Adelaide
  Australia/Brisbane
  Australia/Broken_Hill
  Australia/Darwin
  Australia/Eucla
  Australia/Hobart
  Australia/Lindeman
  Australia/Lord_Howe
  Australia/Melbourne
  Australia/Perth
  Australia/Sydney
  Europe/Andorra
  Europe/Astrakhan
  Europe/Athens
  Europe/Belgrade
  Europe/Berlin
  Europe/Brussels
  Europe/Bucharest
  Europe/Budapest
  Europe/Chisinau
  Europe/Dublin
  Europe/Gibraltar
  Europe/Helsinki
  Europe/Istanbul
  Europe/Kaliningrad
  Europe/Kirov
  Europe/Kyiv
  Europe/Lisbon
  Europe/London
  Europe/Madrid
  Europe/Malta
  Europe/Minsk
  Europe/Moscow
  Europe/Paris
  Europe/Prague
  Europe/Riga
  Europe/Rome
  Europe/Samara
  Europe/Saratov
  Europe/Simferopol
  Europe/Sofia
  Europe/Tallinn
  Europe/Tirane
  Europe/Ulyanovsk
  Europe/Vienna
  Europe/Vilnius
  Europe/Volgograd
  Europe/Warsaw
  Europe/Zurich
  Indian/Chagos
  Indian/Maldives
  Indian/Mauritius
  Pacific/Apia
  Pacific/Auckland
  Pacific/Bougainville
  Pacific/Chatham
  Pacific/Easter
  Pacific/Efate
  Pacific/Fakaofo
  Pacific/Fiji
  Pacific/Galapagos
  Pacific/Gambier
  Pacific/Guadalcanal
  Pacific/Guam
  Pacific/Honolulu
  Pacific/Kanton
  Pacific/Kiritimati
  Pacific/Kosrae
  Pacific/Kwajalein
  Pacific/Marquesas
  Pacific/Nauru
  Pacific/Niue
  Pacific/Norfolk
  Pacific/Noumea
  Pacific/Pago_Pago
  Pacific/Palau
  Pacific/Pitcairn
  Pacific/Port_Moresby
  Pacific/Rarotonga
  Pacific/Tahiti
  Pacific/Tarawa
  Pacific/Tongatapu
  UTC
);

our @CATEGORY_NAMES =
qw(
  Africa
  America
  Antarctica
  Asia
  Atlantic
  Australia
  Europe
  Indian
  Pacific
);

our %CATEGORIES =
(
  'Africa' => [ qw(
Abidjan
Algiers
Bissau
Cairo
Casablanca
Ceuta
El_Aaiun
Johannesburg
Juba
Khartoum
Lagos
Maputo
Monrovia
Nairobi
Ndjamena
Sao_Tome
Tripoli
Tunis
Windhoek
) ],
  'America' => [ qw(
Adak
Anchorage
Araguaina
Argentina/Buenos_Aires
Argentina/Catamarca
Argentina/Cordoba
Argentina/Jujuy
Argentina/La_Rioja
Argentina/Mendoza
Argentina/Rio_Gallegos
Argentina/Salta
Argentina/San_Juan
Argentina/San_Luis
Argentina/Tucuman
Argentina/Ushuaia
Asuncion
Bahia
Bahia_Banderas
Barbados
Belem
Belize
Boa_Vista
Bogota
Boise
Cambridge_Bay
Campo_Grande
Cancun
Caracas
Cayenne
Chicago
Chihuahua
Ciudad_Juarez
Costa_Rica
Cuiaba
Danmarkshavn
Dawson
Dawson_Creek
Denver
Detroit
Edmonton
Eirunepe
El_Salvador
Fort_Nelson
Fortaleza
Glace_Bay
Goose_Bay
Grand_Turk
Guatemala
Guayaquil
Guyana
Halifax
Havana
Hermosillo
Indiana/Indianapolis
Indiana/Knox
Indiana/Marengo
Indiana/Petersburg
Indiana/Tell_City
Indiana/Vevay
Indiana/Vincennes
Indiana/Winamac
Inuvik
Iqaluit
Jamaica
Juneau
Kentucky/Louisville
Kentucky/Monticello
La_Paz
Lima
Los_Angeles
Maceio
Managua
Manaus
Martinique
Matamoros
Mazatlan
Menominee
Merida
Metlakatla
Mexico_City
Miquelon
Moncton
Monterrey
Montevideo
New_York
Nome
Noronha
North_Dakota/Beulah
North_Dakota/Center
North_Dakota/New_Salem
Nuuk
Ojinaga
Panama
Paramaribo
Phoenix
Port-au-Prince
Porto_Velho
Puerto_Rico
Punta_Arenas
Rankin_Inlet
Recife
Regina
Resolute
Rio_Branco
Santarem
Santiago
Santo_Domingo
Sao_Paulo
Scoresbysund
Sitka
St_Johns
Swift_Current
Tegucigalpa
Thule
Tijuana
Toronto
Vancouver
Whitehorse
Winnipeg
Yakutat
) ],
  'Antarctica' => [ qw(
Casey
Davis
Macquarie
Mawson
Palmer
Rothera
Troll
Vostok
) ],
  'Asia' => [ qw(
Almaty
Amman
Anadyr
Aqtau
Aqtobe
Ashgabat
Atyrau
Baghdad
Baku
Bangkok
Barnaul
Beirut
Bishkek
Chita
Colombo
Damascus
Dhaka
Dili
Dubai
Dushanbe
Famagusta
Gaza
Hebron
Ho_Chi_Minh
Hong_Kong
Hovd
Irkutsk
Jakarta
Jayapura
Jerusalem
Kabul
Kamchatka
Karachi
Kathmandu
Khandyga
Kolkata
Krasnoyarsk
Kuching
Macau
Magadan
Makassar
Manila
Nicosia
Novokuznetsk
Novosibirsk
Omsk
Oral
Pontianak
Pyongyang
Qatar
Qostanay
Qyzylorda
Riyadh
Sakhalin
Samarkand
Seoul
Shanghai
Singapore
Srednekolymsk
Taipei
Tashkent
Tbilisi
Tehran
Thimphu
Tokyo
Tomsk
Ulaanbaatar
Urumqi
Ust-Nera
Vladivostok
Yakutsk
Yangon
Yekaterinburg
Yerevan
) ],
  'Atlantic' => [ qw(
Azores
Bermuda
Canary
Cape_Verde
Faroe
Madeira
South_Georgia
Stanley
) ],
  'Australia' => [ qw(
Adelaide
Brisbane
Broken_Hill
Darwin
Eucla
Hobart
Lindeman
Lord_Howe
Melbourne
Perth
Sydney
) ],
  'Europe' => [ qw(
Andorra
Astrakhan
Athens
Belgrade
Berlin
Brussels
Bucharest
Budapest
Chisinau
Dublin
Gibraltar
Helsinki
Istanbul
Kaliningrad
Kirov
Kyiv
Lisbon
London
Madrid
Malta
Minsk
Moscow
Paris
Prague
Riga
Rome
Samara
Saratov
Simferopol
Sofia
Tallinn
Tirane
Ulyanovsk
Vienna
Vilnius
Volgograd
Warsaw
Zurich
) ],
  'Indian' => [ qw(
Chagos
Maldives
Mauritius
) ],
  'Pacific' => [ qw(
Apia
Auckland
Bougainville
Chatham
Easter
Efate
Fakaofo
Fiji
Galapagos
Gambier
Guadalcanal
Guam
Honolulu
Kanton
Kiritimati
Kosrae
Kwajalein
Marquesas
Nauru
Niue
Norfolk
Noumea
Pago_Pago
Palau
Pitcairn
Port_Moresby
Rarotonga
Tahiti
Tarawa
Tongatapu
) ],

);

our %ZONES_BY_COUNTRY =
(
  'ad' => [ qw(
Europe/Andorra
) ],
  'ae' => [ qw(
Asia/Dubai
) ],
  'af' => [ qw(
Asia/Kabul
) ],
  'ag' => [ qw(
America/Antigua
) ],
  'ai' => [ qw(
America/Anguilla
) ],
  'al' => [ qw(
Europe/Tirane
) ],
  'am' => [ qw(
Asia/Yerevan
) ],
  'ao' => [ qw(
Africa/Luanda
) ],
  'aq' => [ qw(
Antarctica/McMurdo
Antarctica/Casey
Antarctica/Davis
Antarctica/DumontDUrville
Antarctica/Mawson
Antarctica/Palmer
Antarctica/Rothera
Antarctica/Syowa
Antarctica/Troll
Antarctica/Vostok
) ],
  'ar' => [ qw(
America/Argentina/Buenos_Aires
America/Argentina/Cordoba
America/Argentina/Salta
America/Argentina/Jujuy
America/Argentina/Tucuman
America/Argentina/Catamarca
America/Argentina/La_Rioja
America/Argentina/San_Juan
America/Argentina/Mendoza
America/Argentina/San_Luis
America/Argentina/Rio_Gallegos
America/Argentina/Ushuaia
) ],
  'as' => [ qw(
Pacific/Pago_Pago
) ],
  'at' => [ qw(
Europe/Vienna
) ],
  'au' => [ qw(
Australia/Lord_Howe
Antarctica/Macquarie
Australia/Hobart
Australia/Melbourne
Australia/Sydney
Australia/Broken_Hill
Australia/Brisbane
Australia/Lindeman
Australia/Adelaide
Australia/Darwin
Australia/Perth
Australia/Eucla
) ],
  'aw' => [ qw(
America/Aruba
) ],
  'ax' => [ qw(
Europe/Mariehamn
) ],
  'az' => [ qw(
Asia/Baku
) ],
  'ba' => [ qw(
Europe/Sarajevo
) ],
  'bb' => [ qw(
America/Barbados
) ],
  'bd' => [ qw(
Asia/Dhaka
) ],
  'be' => [ qw(
Europe/Brussels
) ],
  'bf' => [ qw(
Africa/Ouagadougou
) ],
  'bg' => [ qw(
Europe/Sofia
) ],
  'bh' => [ qw(
Asia/Bahrain
) ],
  'bi' => [ qw(
Africa/Bujumbura
) ],
  'bj' => [ qw(
Africa/Porto-Novo
) ],
  'bl' => [ qw(
America/St_Barthelemy
) ],
  'bm' => [ qw(
Atlantic/Bermuda
) ],
  'bn' => [ qw(
Asia/Brunei
) ],
  'bo' => [ qw(
America/La_Paz
) ],
  'bq' => [ qw(
America/Kralendijk
) ],
  'br' => [ qw(
America/Noronha
America/Belem
America/Fortaleza
America/Recife
America/Araguaina
America/Maceio
America/Bahia
America/Sao_Paulo
America/Campo_Grande
America/Cuiaba
America/Santarem
America/Porto_Velho
America/Boa_Vista
America/Manaus
America/Eirunepe
America/Rio_Branco
) ],
  'bs' => [ qw(
America/Nassau
) ],
  'bt' => [ qw(
Asia/Thimphu
) ],
  'bw' => [ qw(
Africa/Gaborone
) ],
  'by' => [ qw(
Europe/Minsk
) ],
  'bz' => [ qw(
America/Belize
) ],
  'ca' => [ qw(
America/St_Johns
America/Halifax
America/Glace_Bay
America/Moncton
America/Goose_Bay
America/Blanc-Sablon
America/Toronto
America/Iqaluit
America/Atikokan
America/Winnipeg
America/Resolute
America/Rankin_Inlet
America/Regina
America/Swift_Current
America/Edmonton
America/Cambridge_Bay
America/Inuvik
America/Creston
America/Dawson_Creek
America/Fort_Nelson
America/Whitehorse
America/Dawson
America/Vancouver
) ],
  'cc' => [ qw(
Indian/Cocos
) ],
  'cd' => [ qw(
Africa/Kinshasa
Africa/Lubumbashi
) ],
  'cf' => [ qw(
Africa/Bangui
) ],
  'cg' => [ qw(
Africa/Brazzaville
) ],
  'ch' => [ qw(
Europe/Zurich
) ],
  'ci' => [ qw(
Africa/Abidjan
) ],
  'ck' => [ qw(
Pacific/Rarotonga
) ],
  'cl' => [ qw(
America/Santiago
America/Punta_Arenas
Pacific/Easter
) ],
  'cm' => [ qw(
Africa/Douala
) ],
  'cn' => [ qw(
Asia/Shanghai
Asia/Urumqi
) ],
  'co' => [ qw(
America/Bogota
) ],
  'cr' => [ qw(
America/Costa_Rica
) ],
  'cu' => [ qw(
America/Havana
) ],
  'cv' => [ qw(
Atlantic/Cape_Verde
) ],
  'cw' => [ qw(
America/Curacao
) ],
  'cx' => [ qw(
Indian/Christmas
) ],
  'cy' => [ qw(
Asia/Nicosia
Asia/Famagusta
) ],
  'cz' => [ qw(
Europe/Prague
) ],
  'de' => [ qw(
Europe/Berlin
Europe/Busingen
) ],
  'dj' => [ qw(
Africa/Djibouti
) ],
  'dk' => [ qw(
Europe/Copenhagen
) ],
  'dm' => [ qw(
America/Dominica
) ],
  'do' => [ qw(
America/Santo_Domingo
) ],
  'dz' => [ qw(
Africa/Algiers
) ],
  'ec' => [ qw(
America/Guayaquil
Pacific/Galapagos
) ],
  'ee' => [ qw(
Europe/Tallinn
) ],
  'eg' => [ qw(
Africa/Cairo
) ],
  'eh' => [ qw(
Africa/El_Aaiun
) ],
  'er' => [ qw(
Africa/Asmara
) ],
  'es' => [ qw(
Europe/Madrid
Africa/Ceuta
Atlantic/Canary
) ],
  'et' => [ qw(
Africa/Addis_Ababa
) ],
  'fi' => [ qw(
Europe/Helsinki
) ],
  'fj' => [ qw(
Pacific/Fiji
) ],
  'fk' => [ qw(
Atlantic/Stanley
) ],
  'fm' => [ qw(
Pacific/Chuuk
Pacific/Pohnpei
Pacific/Kosrae
) ],
  'fo' => [ qw(
Atlantic/Faroe
) ],
  'fr' => [ qw(
Europe/Paris
) ],
  'ga' => [ qw(
Africa/Libreville
) ],
  'gb' => [ qw(
Europe/London
) ],
  'gd' => [ qw(
America/Grenada
) ],
  'ge' => [ qw(
Asia/Tbilisi
) ],
  'gf' => [ qw(
America/Cayenne
) ],
  'gg' => [ qw(
Europe/Guernsey
) ],
  'gh' => [ qw(
Africa/Accra
) ],
  'gi' => [ qw(
Europe/Gibraltar
) ],
  'gl' => [ qw(
America/Nuuk
America/Danmarkshavn
America/Scoresbysund
America/Thule
) ],
  'gm' => [ qw(
Africa/Banjul
) ],
  'gn' => [ qw(
Africa/Conakry
) ],
  'gp' => [ qw(
America/Guadeloupe
) ],
  'gq' => [ qw(
Africa/Malabo
) ],
  'gr' => [ qw(
Europe/Athens
) ],
  'gs' => [ qw(
Atlantic/South_Georgia
) ],
  'gt' => [ qw(
America/Guatemala
) ],
  'gu' => [ qw(
Pacific/Guam
) ],
  'gw' => [ qw(
Africa/Bissau
) ],
  'gy' => [ qw(
America/Guyana
) ],
  'hk' => [ qw(
Asia/Hong_Kong
) ],
  'hn' => [ qw(
America/Tegucigalpa
) ],
  'hr' => [ qw(
Europe/Zagreb
) ],
  'ht' => [ qw(
America/Port-au-Prince
) ],
  'hu' => [ qw(
Europe/Budapest
) ],
  'id' => [ qw(
Asia/Jakarta
Asia/Pontianak
Asia/Makassar
Asia/Jayapura
) ],
  'ie' => [ qw(
Europe/Dublin
) ],
  'il' => [ qw(
Asia/Jerusalem
) ],
  'im' => [ qw(
Europe/Isle_of_Man
) ],
  'in' => [ qw(
Asia/Kolkata
) ],
  'io' => [ qw(
Indian/Chagos
) ],
  'iq' => [ qw(
Asia/Baghdad
) ],
  'ir' => [ qw(
Asia/Tehran
) ],
  'is' => [ qw(
Atlantic/Reykjavik
) ],
  'it' => [ qw(
Europe/Rome
) ],
  'je' => [ qw(
Europe/Jersey
) ],
  'jm' => [ qw(
America/Jamaica
) ],
  'jo' => [ qw(
Asia/Amman
) ],
  'jp' => [ qw(
Asia/Tokyo
) ],
  'ke' => [ qw(
Africa/Nairobi
) ],
  'kg' => [ qw(
Asia/Bishkek
) ],
  'kh' => [ qw(
Asia/Phnom_Penh
) ],
  'ki' => [ qw(
Pacific/Tarawa
Pacific/Kanton
Pacific/Kiritimati
) ],
  'km' => [ qw(
Indian/Comoro
) ],
  'kn' => [ qw(
America/St_Kitts
) ],
  'kp' => [ qw(
Asia/Pyongyang
) ],
  'kr' => [ qw(
Asia/Seoul
) ],
  'kw' => [ qw(
Asia/Kuwait
) ],
  'ky' => [ qw(
America/Cayman
) ],
  'kz' => [ qw(
Asia/Almaty
Asia/Qyzylorda
Asia/Qostanay
Asia/Aqtobe
Asia/Aqtau
Asia/Atyrau
Asia/Oral
) ],
  'la' => [ qw(
Asia/Vientiane
) ],
  'lb' => [ qw(
Asia/Beirut
) ],
  'lc' => [ qw(
America/St_Lucia
) ],
  'li' => [ qw(
Europe/Vaduz
) ],
  'lk' => [ qw(
Asia/Colombo
) ],
  'lr' => [ qw(
Africa/Monrovia
) ],
  'ls' => [ qw(
Africa/Maseru
) ],
  'lt' => [ qw(
Europe/Vilnius
) ],
  'lu' => [ qw(
Europe/Luxembourg
) ],
  'lv' => [ qw(
Europe/Riga
) ],
  'ly' => [ qw(
Africa/Tripoli
) ],
  'ma' => [ qw(
Africa/Casablanca
) ],
  'mc' => [ qw(
Europe/Monaco
) ],
  'md' => [ qw(
Europe/Chisinau
) ],
  'me' => [ qw(
Europe/Podgorica
) ],
  'mf' => [ qw(
America/Marigot
) ],
  'mg' => [ qw(
Indian/Antananarivo
) ],
  'mh' => [ qw(
Pacific/Majuro
Pacific/Kwajalein
) ],
  'mk' => [ qw(
Europe/Skopje
) ],
  'ml' => [ qw(
Africa/Bamako
) ],
  'mm' => [ qw(
Asia/Yangon
) ],
  'mn' => [ qw(
Asia/Ulaanbaatar
Asia/Hovd
) ],
  'mo' => [ qw(
Asia/Macau
) ],
  'mp' => [ qw(
Pacific/Saipan
) ],
  'mq' => [ qw(
America/Martinique
) ],
  'mr' => [ qw(
Africa/Nouakchott
) ],
  'ms' => [ qw(
America/Montserrat
) ],
  'mt' => [ qw(
Europe/Malta
) ],
  'mu' => [ qw(
Indian/Mauritius
) ],
  'mv' => [ qw(
Indian/Maldives
) ],
  'mw' => [ qw(
Africa/Blantyre
) ],
  'mx' => [ qw(
America/Mexico_City
America/Cancun
America/Merida
America/Monterrey
America/Matamoros
America/Chihuahua
America/Ciudad_Juarez
America/Ojinaga
America/Mazatlan
America/Bahia_Banderas
America/Hermosillo
America/Tijuana
) ],
  'my' => [ qw(
Asia/Kuala_Lumpur
Asia/Kuching
) ],
  'mz' => [ qw(
Africa/Maputo
) ],
  'na' => [ qw(
Africa/Windhoek
) ],
  'nc' => [ qw(
Pacific/Noumea
) ],
  'ne' => [ qw(
Africa/Niamey
) ],
  'nf' => [ qw(
Pacific/Norfolk
) ],
  'ng' => [ qw(
Africa/Lagos
) ],
  'ni' => [ qw(
America/Managua
) ],
  'nl' => [ qw(
Europe/Amsterdam
) ],
  'no' => [ qw(
Europe/Oslo
) ],
  'np' => [ qw(
Asia/Kathmandu
) ],
  'nr' => [ qw(
Pacific/Nauru
) ],
  'nu' => [ qw(
Pacific/Niue
) ],
  'nz' => [ qw(
Pacific/Auckland
Pacific/Chatham
) ],
  'om' => [ qw(
Asia/Muscat
) ],
  'pa' => [ qw(
America/Panama
) ],
  'pe' => [ qw(
America/Lima
) ],
  'pf' => [ qw(
Pacific/Tahiti
Pacific/Marquesas
Pacific/Gambier
) ],
  'pg' => [ qw(
Pacific/Port_Moresby
Pacific/Bougainville
) ],
  'ph' => [ qw(
Asia/Manila
) ],
  'pk' => [ qw(
Asia/Karachi
) ],
  'pl' => [ qw(
Europe/Warsaw
) ],
  'pm' => [ qw(
America/Miquelon
) ],
  'pn' => [ qw(
Pacific/Pitcairn
) ],
  'pr' => [ qw(
America/Puerto_Rico
) ],
  'ps' => [ qw(
Asia/Gaza
Asia/Hebron
) ],
  'pt' => [ qw(
Europe/Lisbon
Atlantic/Madeira
Atlantic/Azores
) ],
  'pw' => [ qw(
Pacific/Palau
) ],
  'py' => [ qw(
America/Asuncion
) ],
  'qa' => [ qw(
Asia/Qatar
) ],
  're' => [ qw(
Indian/Reunion
) ],
  'ro' => [ qw(
Europe/Bucharest
) ],
  'rs' => [ qw(
Europe/Belgrade
) ],
  'ru' => [ qw(
Europe/Kaliningrad
Europe/Moscow
Europe/Kirov
Europe/Volgograd
Europe/Astrakhan
Europe/Saratov
Europe/Ulyanovsk
Europe/Samara
Asia/Yekaterinburg
Asia/Omsk
Asia/Novosibirsk
Asia/Barnaul
Asia/Tomsk
Asia/Novokuznetsk
Asia/Krasnoyarsk
Asia/Irkutsk
Asia/Chita
Asia/Yakutsk
Asia/Khandyga
Asia/Vladivostok
Asia/Ust-Nera
Asia/Magadan
Asia/Sakhalin
Asia/Srednekolymsk
Asia/Kamchatka
Asia/Anadyr
) ],
  'rw' => [ qw(
Africa/Kigali
) ],
  'sa' => [ qw(
Asia/Riyadh
) ],
  'sb' => [ qw(
Pacific/Guadalcanal
) ],
  'sc' => [ qw(
Indian/Mahe
) ],
  'sd' => [ qw(
Africa/Khartoum
) ],
  'se' => [ qw(
Europe/Stockholm
) ],
  'sg' => [ qw(
Asia/Singapore
) ],
  'sh' => [ qw(
Atlantic/St_Helena
) ],
  'si' => [ qw(
Europe/Ljubljana
) ],
  'sj' => [ qw(
Arctic/Longyearbyen
) ],
  'sk' => [ qw(
Europe/Bratislava
) ],
  'sl' => [ qw(
Africa/Freetown
) ],
  'sm' => [ qw(
Europe/San_Marino
) ],
  'sn' => [ qw(
Africa/Dakar
) ],
  'so' => [ qw(
Africa/Mogadishu
) ],
  'sr' => [ qw(
America/Paramaribo
) ],
  'ss' => [ qw(
Africa/Juba
) ],
  'st' => [ qw(
Africa/Sao_Tome
) ],
  'sv' => [ qw(
America/El_Salvador
) ],
  'sx' => [ qw(
America/Lower_Princes
) ],
  'sy' => [ qw(
Asia/Damascus
) ],
  'sz' => [ qw(
Africa/Mbabane
) ],
  'tc' => [ qw(
America/Grand_Turk
) ],
  'td' => [ qw(
Africa/Ndjamena
) ],
  'tf' => [ qw(
Indian/Kerguelen
) ],
  'tg' => [ qw(
Africa/Lome
) ],
  'th' => [ qw(
Asia/Bangkok
) ],
  'tj' => [ qw(
Asia/Dushanbe
) ],
  'tk' => [ qw(
Pacific/Fakaofo
) ],
  'tl' => [ qw(
Asia/Dili
) ],
  'tm' => [ qw(
Asia/Ashgabat
) ],
  'tn' => [ qw(
Africa/Tunis
) ],
  'to' => [ qw(
Pacific/Tongatapu
) ],
  'tr' => [ qw(
Europe/Istanbul
) ],
  'tt' => [ qw(
America/Port_of_Spain
) ],
  'tv' => [ qw(
Pacific/Funafuti
) ],
  'tw' => [ qw(
Asia/Taipei
) ],
  'tz' => [ qw(
Africa/Dar_es_Salaam
) ],
  'ua' => [ qw(
Europe/Simferopol
Europe/Kyiv
) ],
  'ug' => [ qw(
Africa/Kampala
) ],
  'uk' => [ qw(
Europe/London
) ],
  'um' => [ qw(
Pacific/Midway
Pacific/Wake
) ],
  'us' => [ qw(
America/New_York
America/Detroit
America/Kentucky/Louisville
America/Kentucky/Monticello
America/Indiana/Indianapolis
America/Indiana/Vincennes
America/Indiana/Winamac
America/Indiana/Marengo
America/Indiana/Petersburg
America/Indiana/Vevay
America/Chicago
America/Indiana/Tell_City
America/Indiana/Knox
America/Menominee
America/North_Dakota/Center
America/North_Dakota/New_Salem
America/North_Dakota/Beulah
America/Denver
America/Boise
America/Phoenix
America/Los_Angeles
America/Anchorage
America/Juneau
America/Sitka
America/Metlakatla
America/Yakutat
America/Nome
America/Adak
Pacific/Honolulu
) ],
  'uy' => [ qw(
America/Montevideo
) ],
  'uz' => [ qw(
Asia/Samarkand
Asia/Tashkent
) ],
  'va' => [ qw(
Europe/Vatican
) ],
  'vc' => [ qw(
America/St_Vincent
) ],
  've' => [ qw(
America/Caracas
) ],
  'vg' => [ qw(
America/Tortola
) ],
  'vi' => [ qw(
America/St_Thomas
) ],
  'vn' => [ qw(
Asia/Ho_Chi_Minh
) ],
  'vu' => [ qw(
Pacific/Efate
) ],
  'wf' => [ qw(
Pacific/Wallis
) ],
  'ws' => [ qw(
Pacific/Apia
) ],
  'ye' => [ qw(
Asia/Aden
) ],
  'yt' => [ qw(
Indian/Mayotte
) ],
  'za' => [ qw(
Africa/Johannesburg
) ],
  'zm' => [ qw(
Africa/Lusaka
) ],
  'zw' => [ qw(
Africa/Harare
) ],

);

our %LINKS =
(
  'AKST9AKDT' => 'America/Anchorage',
  'Africa/Accra' => 'Africa/Abidjan',
  'Africa/Addis_Ababa' => 'Africa/Nairobi',
  'Africa/Asmara' => 'Africa/Nairobi',
  'Africa/Asmera' => 'Africa/Nairobi',
  'Africa/Bamako' => 'Africa/Abidjan',
  'Africa/Bangui' => 'Africa/Lagos',
  'Africa/Banjul' => 'Africa/Abidjan',
  'Africa/Blantyre' => 'Africa/Maputo',
  'Africa/Brazzaville' => 'Africa/Lagos',
  'Africa/Bujumbura' => 'Africa/Maputo',
  'Africa/Conakry' => 'Africa/Abidjan',
  'Africa/Dakar' => 'Africa/Abidjan',
  'Africa/Dar_es_Salaam' => 'Africa/Nairobi',
  'Africa/Djibouti' => 'Africa/Nairobi',
  'Africa/Douala' => 'Africa/Lagos',
  'Africa/Freetown' => 'Africa/Abidjan',
  'Africa/Gaborone' => 'Africa/Maputo',
  'Africa/Harare' => 'Africa/Maputo',
  'Africa/Kampala' => 'Africa/Nairobi',
  'Africa/Kigali' => 'Africa/Maputo',
  'Africa/Kinshasa' => 'Africa/Lagos',
  'Africa/Libreville' => 'Africa/Lagos',
  'Africa/Lome' => 'Africa/Abidjan',
  'Africa/Luanda' => 'Africa/Lagos',
  'Africa/Lubumbashi' => 'Africa/Maputo',
  'Africa/Lusaka' => 'Africa/Maputo',
  'Africa/Malabo' => 'Africa/Lagos',
  'Africa/Maseru' => 'Africa/Johannesburg',
  'Africa/Mbabane' => 'Africa/Johannesburg',
  'Africa/Mogadishu' => 'Africa/Nairobi',
  'Africa/Niamey' => 'Africa/Lagos',
  'Africa/Nouakchott' => 'Africa/Abidjan',
  'Africa/Ouagadougou' => 'Africa/Abidjan',
  'Africa/Porto-Novo' => 'Africa/Lagos',
  'Africa/Timbuktu' => 'Africa/Abidjan',
  'America/Anguilla' => 'America/Puerto_Rico',
  'America/Antigua' => 'America/Puerto_Rico',
  'America/Argentina/ComodRivadavia' => 'America/Argentina/Catamarca',
  'America/Aruba' => 'America/Puerto_Rico',
  'America/Atikokan' => 'America/Panama',
  'America/Atka' => 'America/Adak',
  'America/Blanc-Sablon' => 'America/Puerto_Rico',
  'America/Buenos_Aires' => 'America/Argentina/Buenos_Aires',
  'America/Catamarca' => 'America/Argentina/Catamarca',
  'America/Cayman' => 'America/Panama',
  'America/Coral_Harbour' => 'America/Panama',
  'America/Cordoba' => 'America/Argentina/Cordoba',
  'America/Creston' => 'America/Phoenix',
  'America/Curacao' => 'America/Puerto_Rico',
  'America/Dominica' => 'America/Puerto_Rico',
  'America/Ensenada' => 'America/Tijuana',
  'America/Fort_Wayne' => 'America/Indiana/Indianapolis',
  'America/Godthab' => 'America/Nuuk',
  'America/Grenada' => 'America/Puerto_Rico',
  'America/Guadeloupe' => 'America/Puerto_Rico',
  'America/Indianapolis' => 'America/Indiana/Indianapolis',
  'America/Jujuy' => 'America/Argentina/Jujuy',
  'America/Knox_IN' => 'America/Indiana/Knox',
  'America/Kralendijk' => 'America/Puerto_Rico',
  'America/Louisville' => 'America/Kentucky/Louisville',
  'America/Lower_Princes' => 'America/Puerto_Rico',
  'America/Marigot' => 'America/Puerto_Rico',
  'America/Mendoza' => 'America/Argentina/Mendoza',
  'America/Montreal' => 'America/Toronto',
  'America/Montserrat' => 'America/Puerto_Rico',
  'America/Nassau' => 'America/Toronto',
  'America/Nipigon' => 'America/Toronto',
  'America/Pangnirtung' => 'America/Iqaluit',
  'America/Port_of_Spain' => 'America/Puerto_Rico',
  'America/Porto_Acre' => 'America/Rio_Branco',
  'America/Rainy_River' => 'America/Winnipeg',
  'America/Rosario' => 'America/Argentina/Cordoba',
  'America/Santa_Isabel' => 'America/Tijuana',
  'America/Shiprock' => 'America/Denver',
  'America/St_Barthelemy' => 'America/Puerto_Rico',
  'America/St_Kitts' => 'America/Puerto_Rico',
  'America/St_Lucia' => 'America/Puerto_Rico',
  'America/St_Thomas' => 'America/Puerto_Rico',
  'America/St_Vincent' => 'America/Puerto_Rico',
  'America/Thunder_Bay' => 'America/Toronto',
  'America/Tortola' => 'America/Puerto_Rico',
  'America/Virgin' => 'America/Puerto_Rico',
  'America/Yellowknife' => 'America/Edmonton',
  'Antarctica/DumontDUrville' => 'Pacific/Port_Moresby',
  'Antarctica/McMurdo' => 'Pacific/Auckland',
  'Antarctica/South_Pole' => 'Pacific/Auckland',
  'Antarctica/Syowa' => 'Asia/Riyadh',
  'Arctic/Longyearbyen' => 'Europe/Berlin',
  'Asia/Aden' => 'Asia/Riyadh',
  'Asia/Ashkhabad' => 'Asia/Ashgabat',
  'Asia/Bahrain' => 'Asia/Qatar',
  'Asia/Brunei' => 'Asia/Kuching',
  'Asia/Calcutta' => 'Asia/Kolkata',
  'Asia/Choibalsan' => 'Asia/Ulaanbaatar',
  'Asia/Chongqing' => 'Asia/Shanghai',
  'Asia/Chungking' => 'Asia/Shanghai',
  'Asia/Dacca' => 'Asia/Dhaka',
  'Asia/Harbin' => 'Asia/Shanghai',
  'Asia/Istanbul' => 'Europe/Istanbul',
  'Asia/Kashgar' => 'Asia/Urumqi',
  'Asia/Katmandu' => 'Asia/Kathmandu',
  'Asia/Kuala_Lumpur' => 'Asia/Singapore',
  'Asia/Kuwait' => 'Asia/Riyadh',
  'Asia/Macao' => 'Asia/Macau',
  'Asia/Muscat' => 'Asia/Dubai',
  'Asia/Phnom_Penh' => 'Asia/Bangkok',
  'Asia/Rangoon' => 'Asia/Yangon',
  'Asia/Saigon' => 'Asia/Ho_Chi_Minh',
  'Asia/Tel_Aviv' => 'Asia/Jerusalem',
  'Asia/Thimbu' => 'Asia/Thimphu',
  'Asia/Ujung_Pandang' => 'Asia/Makassar',
  'Asia/Ulan_Bator' => 'Asia/Ulaanbaatar',
  'Asia/Vientiane' => 'Asia/Bangkok',
  'Atlantic/Faeroe' => 'Atlantic/Faroe',
  'Atlantic/Jan_Mayen' => 'Europe/Berlin',
  'Atlantic/Reykjavik' => 'Africa/Abidjan',
  'Atlantic/St_Helena' => 'Africa/Abidjan',
  'Australia/ACT' => 'Australia/Sydney',
  'Australia/Canberra' => 'Australia/Sydney',
  'Australia/Currie' => 'Australia/Hobart',
  'Australia/LHI' => 'Australia/Lord_Howe',
  'Australia/NSW' => 'Australia/Sydney',
  'Australia/North' => 'Australia/Darwin',
  'Australia/Queensland' => 'Australia/Brisbane',
  'Australia/South' => 'Australia/Adelaide',
  'Australia/Tasmania' => 'Australia/Hobart',
  'Australia/Victoria' => 'Australia/Melbourne',
  'Australia/West' => 'Australia/Perth',
  'Australia/Yancowinna' => 'Australia/Broken_Hill',
  'Brazil/Acre' => 'America/Rio_Branco',
  'Brazil/DeNoronha' => 'America/Noronha',
  'Brazil/East' => 'America/Sao_Paulo',
  'Brazil/West' => 'America/Manaus',
  'CET' => 'Europe/Brussels',
  'CST6CDT' => 'America/Chicago',
  'Canada/Atlantic' => 'America/Halifax',
  'Canada/Central' => 'America/Winnipeg',
  'Canada/Eastern' => 'America/Toronto',
  'Canada/Mountain' => 'America/Edmonton',
  'Canada/Newfoundland' => 'America/St_Johns',
  'Canada/Pacific' => 'America/Vancouver',
  'Canada/Saskatchewan' => 'America/Regina',
  'Canada/Yukon' => 'America/Whitehorse',
  'Chile/Continental' => 'America/Santiago',
  'Chile/EasterIsland' => 'Pacific/Easter',
  'Cuba' => 'America/Havana',
  'EET' => 'Europe/Athens',
  'EST' => 'America/Panama',
  'EST5EDT' => 'America/New_York',
  'Egypt' => 'Africa/Cairo',
  'Eire' => 'Europe/Dublin',
  'Etc/GMT' => 'UTC',
  'Etc/GMT+0' => 'UTC',
  'Etc/GMT-0' => 'UTC',
  'Etc/GMT0' => 'UTC',
  'Etc/Greenwich' => 'UTC',
  'Etc/UCT' => 'UTC',
  'Etc/UTC' => 'UTC',
  'Etc/Universal' => 'UTC',
  'Etc/Zulu' => 'UTC',
  'Europe/Amsterdam' => 'Europe/Brussels',
  'Europe/Belfast' => 'Europe/London',
  'Europe/Bratislava' => 'Europe/Prague',
  'Europe/Busingen' => 'Europe/Zurich',
  'Europe/Copenhagen' => 'Europe/Berlin',
  'Europe/Guernsey' => 'Europe/London',
  'Europe/Isle_of_Man' => 'Europe/London',
  'Europe/Jersey' => 'Europe/London',
  'Europe/Kiev' => 'Europe/Kyiv',
  'Europe/Ljubljana' => 'Europe/Belgrade',
  'Europe/Luxembourg' => 'Europe/Brussels',
  'Europe/Mariehamn' => 'Europe/Helsinki',
  'Europe/Monaco' => 'Europe/Paris',
  'Europe/Nicosia' => 'Asia/Nicosia',
  'Europe/Oslo' => 'Europe/Berlin',
  'Europe/Podgorica' => 'Europe/Belgrade',
  'Europe/San_Marino' => 'Europe/Rome',
  'Europe/Sarajevo' => 'Europe/Belgrade',
  'Europe/Skopje' => 'Europe/Belgrade',
  'Europe/Stockholm' => 'Europe/Berlin',
  'Europe/Tiraspol' => 'Europe/Chisinau',
  'Europe/Uzhgorod' => 'Europe/Kyiv',
  'Europe/Vaduz' => 'Europe/Zurich',
  'Europe/Vatican' => 'Europe/Rome',
  'Europe/Zagreb' => 'Europe/Belgrade',
  'Europe/Zaporozhye' => 'Europe/Kyiv',
  'GB' => 'Europe/London',
  'GB-Eire' => 'Europe/London',
  'GMT' => 'UTC',
  'GMT+0' => 'UTC',
  'GMT-0' => 'UTC',
  'GMT0' => 'UTC',
  'Greenwich' => 'UTC',
  'HST' => 'Pacific/Honolulu',
  'Hongkong' => 'Asia/Hong_Kong',
  'Iceland' => 'Africa/Abidjan',
  'Indian/Antananarivo' => 'Africa/Nairobi',
  'Indian/Christmas' => 'Asia/Bangkok',
  'Indian/Cocos' => 'Asia/Yangon',
  'Indian/Comoro' => 'Africa/Nairobi',
  'Indian/Kerguelen' => 'Indian/Maldives',
  'Indian/Mahe' => 'Asia/Dubai',
  'Indian/Mayotte' => 'Africa/Nairobi',
  'Indian/Reunion' => 'Asia/Dubai',
  'Iran' => 'Asia/Tehran',
  'Israel' => 'Asia/Jerusalem',
  'JST-9' => 'Asia/Tokyo',
  'Jamaica' => 'America/Jamaica',
  'Japan' => 'Asia/Tokyo',
  'Kwajalein' => 'Pacific/Kwajalein',
  'Libya' => 'Africa/Tripoli',
  'MET' => 'Europe/Brussels',
  'MST' => 'America/Phoenix',
  'MST7MDT' => 'America/Denver',
  'Mexico/BajaNorte' => 'America/Tijuana',
  'Mexico/BajaSur' => 'America/Mazatlan',
  'Mexico/General' => 'America/Mexico_City',
  'NZ' => 'Pacific/Auckland',
  'NZ-CHAT' => 'Pacific/Chatham',
  'Navajo' => 'America/Denver',
  'PRC' => 'Asia/Shanghai',
  'PST8PDT' => 'America/Los_Angeles',
  'Pacific/Chuuk' => 'Pacific/Port_Moresby',
  'Pacific/Enderbury' => 'Pacific/Kanton',
  'Pacific/Funafuti' => 'Pacific/Tarawa',
  'Pacific/Johnston' => 'Pacific/Honolulu',
  'Pacific/Majuro' => 'Pacific/Tarawa',
  'Pacific/Midway' => 'Pacific/Pago_Pago',
  'Pacific/Pohnpei' => 'Pacific/Guadalcanal',
  'Pacific/Ponape' => 'Pacific/Guadalcanal',
  'Pacific/Saipan' => 'Pacific/Guam',
  'Pacific/Samoa' => 'Pacific/Pago_Pago',
  'Pacific/Truk' => 'Pacific/Port_Moresby',
  'Pacific/Wake' => 'Pacific/Tarawa',
  'Pacific/Wallis' => 'Pacific/Tarawa',
  'Pacific/Yap' => 'Pacific/Port_Moresby',
  'Poland' => 'Europe/Warsaw',
  'Portugal' => 'Europe/Lisbon',
  'ROC' => 'Asia/Taipei',
  'ROK' => 'Asia/Seoul',
  'Singapore' => 'Asia/Singapore',
  'Turkey' => 'Europe/Istanbul',
  'UCT' => 'UTC',
  'US/Alaska' => 'America/Anchorage',
  'US/Aleutian' => 'America/Adak',
  'US/Arizona' => 'America/Phoenix',
  'US/Central' => 'America/Chicago',
  'US/East-Indiana' => 'America/Indiana/Indianapolis',
  'US/Eastern' => 'America/New_York',
  'US/Hawaii' => 'Pacific/Honolulu',
  'US/Indiana-Starke' => 'America/Indiana/Knox',
  'US/Michigan' => 'America/Detroit',
  'US/Mountain' => 'America/Denver',
  'US/Pacific' => 'America/Los_Angeles',
  'US/Samoa' => 'Pacific/Pago_Pago',
  'Universal' => 'UTC',
  'W-SU' => 'Europe/Moscow',
  'WET' => 'Europe/Lisbon',
  'Zulu' => 'UTC'
)

;

sub OlsonVersion { '2025a' }


1;

__END__

=pod

=head1 NAME

DateTime::TimeZone::Catalog - Provides a list of all valid time zone names

=head1 DESCRIPTION

This module contains an enumerated list of all known system timezones,
so that applications can easily present a list of timezones.

=head1 AVAILABLE ZONES

=head2 Zones by Continent/Region

=head3 Africa

  Africa/Abidjan
  Africa/Algiers
  Africa/Bissau
  Africa/Cairo
  Africa/Casablanca
  Africa/El_Aaiun
  Africa/Johannesburg
  Africa/Juba
  Africa/Khartoum
  Africa/Lagos
  Africa/Maputo
  Africa/Monrovia
  Africa/Nairobi
  Africa/Ndjamena
  Africa/Sao_Tome
  Africa/Tripoli
  Africa/Tunis
  Africa/Windhoek
  Africa/Ceuta

=head3 America

  America/Araguaina
  America/Argentina/Buenos_Aires
  America/Argentina/Catamarca
  America/Argentina/Cordoba
  America/Argentina/Jujuy
  America/Argentina/La_Rioja
  America/Argentina/Mendoza
  America/Argentina/Rio_Gallegos
  America/Argentina/Salta
  America/Argentina/San_Juan
  America/Argentina/San_Luis
  America/Argentina/Tucuman
  America/Argentina/Ushuaia
  America/Asuncion
  America/Bahia
  America/Belem
  America/Boa_Vista
  America/Bogota
  America/Campo_Grande
  America/Caracas
  America/Cayenne
  America/Cuiaba
  America/Eirunepe
  America/Fortaleza
  America/Guayaquil
  America/Guyana
  America/La_Paz
  America/Lima
  America/Maceio
  America/Manaus
  America/Montevideo
  America/Noronha
  America/Paramaribo
  America/Porto_Velho
  America/Punta_Arenas
  America/Recife
  America/Rio_Branco
  America/Santarem
  America/Santiago
  America/Sao_Paulo
  America/Danmarkshavn
  America/Nuuk
  America/Scoresbysund
  America/Thule
  America/Adak
  America/Anchorage
  America/Bahia_Banderas
  America/Barbados
  America/Belize
  America/Boise
  America/Cambridge_Bay
  America/Cancun
  America/Chicago
  America/Chihuahua
  America/Ciudad_Juarez
  America/Costa_Rica
  America/Dawson
  America/Dawson_Creek
  America/Denver
  America/Detroit
  America/Edmonton
  America/El_Salvador
  America/Fort_Nelson
  America/Glace_Bay
  America/Goose_Bay
  America/Grand_Turk
  America/Guatemala
  America/Halifax
  America/Havana
  America/Hermosillo
  America/Indiana/Indianapolis
  America/Indiana/Knox
  America/Indiana/Marengo
  America/Indiana/Petersburg
  America/Indiana/Tell_City
  America/Indiana/Vevay
  America/Indiana/Vincennes
  America/Indiana/Winamac
  America/Inuvik
  America/Iqaluit
  America/Jamaica
  America/Juneau
  America/Kentucky/Louisville
  America/Kentucky/Monticello
  America/Los_Angeles
  America/Managua
  America/Martinique
  America/Matamoros
  America/Mazatlan
  America/Menominee
  America/Merida
  America/Metlakatla
  America/Mexico_City
  America/Miquelon
  America/Moncton
  America/Monterrey
  America/New_York
  America/Nome
  America/North_Dakota/Beulah
  America/North_Dakota/Center
  America/North_Dakota/New_Salem
  America/Ojinaga
  America/Panama
  America/Phoenix
  America/Port-au-Prince
  America/Puerto_Rico
  America/Rankin_Inlet
  America/Regina
  America/Resolute
  America/Santo_Domingo
  America/Sitka
  America/St_Johns
  America/Swift_Current
  America/Tegucigalpa
  America/Tijuana
  America/Toronto
  America/Vancouver
  America/Whitehorse
  America/Winnipeg
  America/Yakutat

=head3 Antarctica

  Antarctica/Casey
  Antarctica/Davis
  Antarctica/Mawson
  Antarctica/Rothera
  Antarctica/Troll
  Antarctica/Vostok
  Antarctica/Macquarie
  Antarctica/Palmer

=head3 Asia

  Asia/Almaty
  Asia/Amman
  Asia/Aqtau
  Asia/Aqtobe
  Asia/Ashgabat
  Asia/Atyrau
  Asia/Baghdad
  Asia/Baku
  Asia/Bangkok
  Asia/Beirut
  Asia/Bishkek
  Asia/Colombo
  Asia/Damascus
  Asia/Dhaka
  Asia/Dili
  Asia/Dubai
  Asia/Dushanbe
  Asia/Famagusta
  Asia/Gaza
  Asia/Hebron
  Asia/Ho_Chi_Minh
  Asia/Hong_Kong
  Asia/Hovd
  Asia/Jakarta
  Asia/Jayapura
  Asia/Jerusalem
  Asia/Kabul
  Asia/Karachi
  Asia/Kathmandu
  Asia/Kolkata
  Asia/Kuching
  Asia/Macau
  Asia/Makassar
  Asia/Manila
  Asia/Nicosia
  Asia/Oral
  Asia/Pontianak
  Asia/Pyongyang
  Asia/Qatar
  Asia/Qostanay
  Asia/Qyzylorda
  Asia/Riyadh
  Asia/Samarkand
  Asia/Seoul
  Asia/Shanghai
  Asia/Singapore
  Asia/Taipei
  Asia/Tashkent
  Asia/Tbilisi
  Asia/Tehran
  Asia/Thimphu
  Asia/Tokyo
  Asia/Ulaanbaatar
  Asia/Urumqi
  Asia/Yangon
  Asia/Yerevan
  Asia/Anadyr
  Asia/Barnaul
  Asia/Chita
  Asia/Irkutsk
  Asia/Kamchatka
  Asia/Khandyga
  Asia/Krasnoyarsk
  Asia/Magadan
  Asia/Novokuznetsk
  Asia/Novosibirsk
  Asia/Omsk
  Asia/Sakhalin
  Asia/Srednekolymsk
  Asia/Tomsk
  Asia/Ust-Nera
  Asia/Vladivostok
  Asia/Yakutsk
  Asia/Yekaterinburg

=head3 Atlantic

  Atlantic/Cape_Verde
  Atlantic/South_Georgia
  Atlantic/Stanley
  Atlantic/Azores
  Atlantic/Canary
  Atlantic/Faroe
  Atlantic/Madeira
  Atlantic/Bermuda

=head3 Australia

  Australia/Adelaide
  Australia/Brisbane
  Australia/Broken_Hill
  Australia/Darwin
  Australia/Eucla
  Australia/Hobart
  Australia/Lindeman
  Australia/Lord_Howe
  Australia/Melbourne
  Australia/Perth
  Australia/Sydney

=head3 Europe

  Europe/Andorra
  Europe/Astrakhan
  Europe/Athens
  Europe/Belgrade
  Europe/Berlin
  Europe/Brussels
  Europe/Bucharest
  Europe/Budapest
  Europe/Chisinau
  Europe/Dublin
  Europe/Gibraltar
  Europe/Helsinki
  Europe/Istanbul
  Europe/Kaliningrad
  Europe/Kirov
  Europe/Kyiv
  Europe/Lisbon
  Europe/London
  Europe/Madrid
  Europe/Malta
  Europe/Minsk
  Europe/Moscow
  Europe/Paris
  Europe/Prague
  Europe/Riga
  Europe/Rome
  Europe/Samara
  Europe/Saratov
  Europe/Simferopol
  Europe/Sofia
  Europe/Tallinn
  Europe/Tirane
  Europe/Ulyanovsk
  Europe/Vienna
  Europe/Vilnius
  Europe/Volgograd
  Europe/Warsaw
  Europe/Zurich

=head3 Indian

  Indian/Mauritius
  Indian/Chagos
  Indian/Maldives

=head3 Pacific

  Pacific/Apia
  Pacific/Auckland
  Pacific/Bougainville
  Pacific/Chatham
  Pacific/Efate
  Pacific/Fakaofo
  Pacific/Fiji
  Pacific/Gambier
  Pacific/Guadalcanal
  Pacific/Guam
  Pacific/Kanton
  Pacific/Kiritimati
  Pacific/Kosrae
  Pacific/Kwajalein
  Pacific/Marquesas
  Pacific/Nauru
  Pacific/Niue
  Pacific/Norfolk
  Pacific/Noumea
  Pacific/Pago_Pago
  Pacific/Palau
  Pacific/Pitcairn
  Pacific/Port_Moresby
  Pacific/Rarotonga
  Pacific/Tahiti
  Pacific/Tarawa
  Pacific/Tongatapu
  Pacific/Easter
  Pacific/Galapagos
  Pacific/Honolulu

=head2 Zones by Country

=head3 Afghanistan (AF)

  Asia/Kabul

=head3 Aland Islands (AX)

  Europe/Mariehamn

=head3 Albania (AL)

  Europe/Tirane

=head3 Algeria (DZ)

  Africa/Algiers

=head3 American Samoa (AS)

  Pacific/Pago_Pago

=head3 Andorra (AD)

  Europe/Andorra

=head3 Angola (AO)

  Africa/Luanda

=head3 Anguilla (AI)

  America/Anguilla

=head3 Antarctica (AQ)

  Antarctica/McMurdo - New Zealand time - McMurdo, South Pole
  Antarctica/Casey - Casey
  Antarctica/Davis - Davis
  Antarctica/DumontDUrville - Dumont-d'Urville
  Antarctica/Mawson - Mawson
  Antarctica/Palmer - Palmer
  Antarctica/Rothera - Rothera
  Antarctica/Syowa - Syowa
  Antarctica/Troll - Troll
  Antarctica/Vostok - Vostok

=head3 Antigua and Barbuda (AG)

  America/Antigua

=head3 Argentina (AR)

  America/Argentina/Buenos_Aires - Buenos Aires (BA, CF)
  America/Argentina/Cordoba - Argentina (most areas: CB, CC, CN, ER, FM, MN, SE, SF)
  America/Argentina/Salta - Salta (SA, LP, NQ, RN)
  America/Argentina/Jujuy - Jujuy (JY)
  America/Argentina/Tucuman - Tucuman (TM)
  America/Argentina/Catamarca - Catamarca (CT), Chubut (CH)
  America/Argentina/La_Rioja - La Rioja (LR)
  America/Argentina/San_Juan - San Juan (SJ)
  America/Argentina/Mendoza - Mendoza (MZ)
  America/Argentina/San_Luis - San Luis (SL)
  America/Argentina/Rio_Gallegos - Santa Cruz (SC)
  America/Argentina/Ushuaia - Tierra del Fuego (TF)

=head3 Armenia (AM)

  Asia/Yerevan

=head3 Aruba (AW)

  America/Aruba

=head3 Australia (AU)

  Australia/Lord_Howe - Lord Howe Island
  Antarctica/Macquarie - Macquarie Island
  Australia/Hobart - Tasmania
  Australia/Melbourne - Victoria
  Australia/Sydney - New South Wales (most areas)
  Australia/Broken_Hill - New South Wales (Yancowinna)
  Australia/Brisbane - Queensland (most areas)
  Australia/Lindeman - Queensland (Whitsunday Islands)
  Australia/Adelaide - South Australia
  Australia/Darwin - Northern Territory
  Australia/Perth - Western Australia (most areas)
  Australia/Eucla - Western Australia (Eucla)

=head3 Austria (AT)

  Europe/Vienna

=head3 Azerbaijan (AZ)

  Asia/Baku

=head3 Bahamas (BS)

  America/Nassau

=head3 Bahrain (BH)

  Asia/Bahrain

=head3 Bangladesh (BD)

  Asia/Dhaka

=head3 Barbados (BB)

  America/Barbados

=head3 Belarus (BY)

  Europe/Minsk

=head3 Belgium (BE)

  Europe/Brussels

=head3 Belize (BZ)

  America/Belize

=head3 Benin (BJ)

  Africa/Porto-Novo

=head3 Bermuda (BM)

  Atlantic/Bermuda

=head3 Bhutan (BT)

  Asia/Thimphu

=head3 Bolivia (Plurinational State of) (BO)

  America/La_Paz

=head3 Bonaire, Sint Eustatius and Saba (BQ)

  America/Kralendijk

=head3 Bosnia and Herzegovina (BA)

  Europe/Sarajevo

=head3 Botswana (BW)

  Africa/Gaborone

=head3 Brazil (BR)

  America/Noronha - Atlantic islands
  America/Belem - Para (east), Amapa
  America/Fortaleza - Brazil (northeast: MA, PI, CE, RN, PB)
  America/Recife - Pernambuco
  America/Araguaina - Tocantins
  America/Maceio - Alagoas, Sergipe
  America/Bahia - Bahia
  America/Sao_Paulo - Brazil (southeast: GO, DF, MG, ES, RJ, SP, PR, SC, RS)
  America/Campo_Grande - Mato Grosso do Sul
  America/Cuiaba - Mato Grosso
  America/Santarem - Para (west)
  America/Porto_Velho - Rondonia
  America/Boa_Vista - Roraima
  America/Manaus - Amazonas (east)
  America/Eirunepe - Amazonas (west)
  America/Rio_Branco - Acre

=head3 British Indian Ocean Territory (IO)

  Indian/Chagos

=head3 Brunei Darussalam (BN)

  Asia/Brunei

=head3 Bulgaria (BG)

  Europe/Sofia

=head3 Burkina Faso (BF)

  Africa/Ouagadougou

=head3 Burundi (BI)

  Africa/Bujumbura

=head3 Cabo Verde (CV)

  Atlantic/Cape_Verde

=head3 Cambodia (KH)

  Asia/Phnom_Penh

=head3 Cameroon (CM)

  Africa/Douala

=head3 Canada (CA)

  America/St_Johns - Newfoundland, Labrador (SE)
  America/Halifax - Atlantic - NS (most areas), PE
  America/Glace_Bay - Atlantic - NS (Cape Breton)
  America/Moncton - Atlantic - New Brunswick
  America/Goose_Bay - Atlantic - Labrador (most areas)
  America/Blanc-Sablon - AST - QC (Lower North Shore)
  America/Toronto - Eastern - ON & QC (most areas)
  America/Iqaluit - Eastern - NU (most areas)
  America/Atikokan - EST - ON (Atikokan), NU (Coral H)
  America/Winnipeg - Central - ON (west), Manitoba
  America/Resolute - Central - NU (Resolute)
  America/Rankin_Inlet - Central - NU (central)
  America/Regina - CST - SK (most areas)
  America/Swift_Current - CST - SK (midwest)
  America/Edmonton - Mountain - AB, BC(E), NT(E), SK(W)
  America/Cambridge_Bay - Mountain - NU (west)
  America/Inuvik - Mountain - NT (west)
  America/Creston - MST - BC (Creston)
  America/Dawson_Creek - MST - BC (Dawson Cr, Ft St John)
  America/Fort_Nelson - MST - BC (Ft Nelson)
  America/Whitehorse - MST - Yukon (east)
  America/Dawson - MST - Yukon (west)
  America/Vancouver - Pacific - BC (most areas)

=head3 Cayman Islands (KY)

  America/Cayman

=head3 Central African Republic (CF)

  Africa/Bangui

=head3 Chad (TD)

  Africa/Ndjamena

=head3 Chile (CL)

  America/Santiago - most of Chile
  America/Punta_Arenas - Region of Magallanes
  Pacific/Easter - Easter Island

=head3 China (CN)

  Asia/Shanghai - Beijing Time
  Asia/Urumqi - Xinjiang Time

=head3 Christmas Island (CX)

  Indian/Christmas

=head3 Cocos (Keeling) Islands (CC)

  Indian/Cocos

=head3 Colombia (CO)

  America/Bogota

=head3 Comoros (KM)

  Indian/Comoro

=head3 Congo (CG)

  Africa/Brazzaville

=head3 Congo (The Democratic Republic of the) (CD)

  Africa/Kinshasa - Dem. Rep. of Congo (west)
  Africa/Lubumbashi - Dem. Rep. of Congo (east)

=head3 Cook Islands (CK)

  Pacific/Rarotonga

=head3 Costa Rica (CR)

  America/Costa_Rica

=head3 Cote d'Ivoire (CI)

  Africa/Abidjan

=head3 Croatia (HR)

  Europe/Zagreb

=head3 Cuba (CU)

  America/Havana

=head3 Curacao (CW)

  America/Curacao

=head3 Cyprus (CY)

  Asia/Nicosia - most of Cyprus
  Asia/Famagusta - Northern Cyprus

=head3 Czechia (CZ)

  Europe/Prague

=head3 Denmark (DK)

  Europe/Copenhagen

=head3 Djibouti (DJ)

  Africa/Djibouti

=head3 Dominica (DM)

  America/Dominica

=head3 Dominican Republic (DO)

  America/Santo_Domingo

=head3 Ecuador (EC)

  America/Guayaquil - Ecuador (mainland)
  Pacific/Galapagos - Galapagos Islands

=head3 Egypt (EG)

  Africa/Cairo

=head3 El Salvador (SV)

  America/El_Salvador

=head3 Equatorial Guinea (GQ)

  Africa/Malabo

=head3 Eritrea (ER)

  Africa/Asmara

=head3 Estonia (EE)

  Europe/Tallinn

=head3 Eswatini (SZ)

  Africa/Mbabane

=head3 Ethiopia (ET)

  Africa/Addis_Ababa

=head3 Falkland Islands (The) [Malvinas] (FK)

  Atlantic/Stanley

=head3 Faroe Islands (FO)

  Atlantic/Faroe

=head3 Fiji (FJ)

  Pacific/Fiji

=head3 Finland (FI)

  Europe/Helsinki

=head3 France (FR)

  Europe/Paris

=head3 French Guiana (GF)

  America/Cayenne

=head3 French Polynesia (PF)

  Pacific/Tahiti - Society Islands
  Pacific/Marquesas - Marquesas Islands
  Pacific/Gambier - Gambier Islands

=head3 French Southern Territories (TF)

  Indian/Kerguelen

=head3 Gabon (GA)

  Africa/Libreville

=head3 Gambia (GM)

  Africa/Banjul

=head3 Georgia (GE)

  Asia/Tbilisi

=head3 Germany (DE)

  Europe/Berlin - most of Germany
  Europe/Busingen - Busingen

=head3 Ghana (GH)

  Africa/Accra

=head3 Gibraltar (GI)

  Europe/Gibraltar

=head3 Greece (GR)

  Europe/Athens

=head3 Greenland (GL)

  America/Nuuk - most of Greenland
  America/Danmarkshavn - National Park (east coast)
  America/Scoresbysund - Scoresbysund/Ittoqqortoormiit
  America/Thule - Thule/Pituffik

=head3 Grenada (GD)

  America/Grenada

=head3 Guadeloupe (GP)

  America/Guadeloupe

=head3 Guam (GU)

  Pacific/Guam

=head3 Guatemala (GT)

  America/Guatemala

=head3 Guernsey (GG)

  Europe/Guernsey

=head3 Guinea (GN)

  Africa/Conakry

=head3 Guinea-Bissau (GW)

  Africa/Bissau

=head3 Guyana (GY)

  America/Guyana

=head3 Haiti (HT)

  America/Port-au-Prince

=head3 Holy See (VA)

  Europe/Vatican

=head3 Honduras (HN)

  America/Tegucigalpa

=head3 Hong Kong (HK)

  Asia/Hong_Kong

=head3 Hungary (HU)

  Europe/Budapest

=head3 Iceland (IS)

  Atlantic/Reykjavik

=head3 India (IN)

  Asia/Kolkata

=head3 Indonesia (ID)

  Asia/Jakarta - Java, Sumatra
  Asia/Pontianak - Borneo (west, central)
  Asia/Makassar - Borneo (east, south), Sulawesi/Celebes, Bali, Nusa Tengarra, Timor (west)
  Asia/Jayapura - New Guinea (West Papua / Irian Jaya), Malukus/Moluccas

=head3 Iran (Islamic Republic of) (IR)

  Asia/Tehran

=head3 Iraq (IQ)

  Asia/Baghdad

=head3 Ireland (IE)

  Europe/Dublin

=head3 Isle of Man (IM)

  Europe/Isle_of_Man

=head3 Israel (IL)

  Asia/Jerusalem

=head3 Italy (IT)

  Europe/Rome

=head3 Jamaica (JM)

  America/Jamaica

=head3 Japan (JP)

  Asia/Tokyo

=head3 Jersey (JE)

  Europe/Jersey

=head3 Jordan (JO)

  Asia/Amman

=head3 Kazakhstan (KZ)

  Asia/Almaty - most of Kazakhstan
  Asia/Qyzylorda - Qyzylorda/Kyzylorda/Kzyl-Orda
  Asia/Qostanay - Qostanay/Kostanay/Kustanay
  Asia/Aqtobe - Aqtobe/Aktobe
  Asia/Aqtau - Mangghystau/Mankistau
  Asia/Atyrau - Atyrau/Atirau/Gur'yev
  Asia/Oral - West Kazakhstan

=head3 Kenya (KE)

  Africa/Nairobi

=head3 Kiribati (KI)

  Pacific/Tarawa - Gilbert Islands
  Pacific/Kanton - Phoenix Islands
  Pacific/Kiritimati - Line Islands

=head3 Korea, The Democratic People's Republic of (KP)

  Asia/Pyongyang

=head3 Korea, The Republic of (KR)

  Asia/Seoul

=head3 Kuwait (KW)

  Asia/Kuwait

=head3 Kyrgyzstan (KG)

  Asia/Bishkek

=head3 Lao People's Democratic Republic (LA)

  Asia/Vientiane

=head3 Latvia (LV)

  Europe/Riga

=head3 Lebanon (LB)

  Asia/Beirut

=head3 Lesotho (LS)

  Africa/Maseru

=head3 Liberia (LR)

  Africa/Monrovia

=head3 Libya (LY)

  Africa/Tripoli

=head3 Liechtenstein (LI)

  Europe/Vaduz

=head3 Lithuania (LT)

  Europe/Vilnius

=head3 Luxembourg (LU)

  Europe/Luxembourg

=head3 Macao (MO)

  Asia/Macau

=head3 Madagascar (MG)

  Indian/Antananarivo

=head3 Malawi (MW)

  Africa/Blantyre

=head3 Malaysia (MY)

  Asia/Kuala_Lumpur - Malaysia (peninsula)
  Asia/Kuching - Sabah, Sarawak

=head3 Maldives (MV)

  Indian/Maldives

=head3 Mali (ML)

  Africa/Bamako

=head3 Malta (MT)

  Europe/Malta

=head3 Marshall Islands (MH)

  Pacific/Majuro - most of Marshall Islands
  Pacific/Kwajalein - Kwajalein

=head3 Martinique (MQ)

  America/Martinique

=head3 Mauritania (MR)

  Africa/Nouakchott

=head3 Mauritius (MU)

  Indian/Mauritius

=head3 Mayotte (YT)

  Indian/Mayotte

=head3 Mexico (MX)

  America/Mexico_City - Central Mexico
  America/Cancun - Quintana Roo
  America/Merida - Campeche, Yucatan
  America/Monterrey - Durango; Coahuila, Nuevo Leon, Tamaulipas (most areas)
  America/Matamoros - Coahuila, Nuevo Leon, Tamaulipas (US border)
  America/Chihuahua - Chihuahua (most areas)
  America/Ciudad_Juarez - Chihuahua (US border - west)
  America/Ojinaga - Chihuahua (US border - east)
  America/Mazatlan - Baja California Sur, Nayarit (most areas), Sinaloa
  America/Bahia_Banderas - Bahia de Banderas
  America/Hermosillo - Sonora
  America/Tijuana - Baja California

=head3 Micronesia (Federated States of) (FM)

  Pacific/Chuuk - Chuuk/Truk, Yap
  Pacific/Pohnpei - Pohnpei/Ponape
  Pacific/Kosrae - Kosrae

=head3 Moldova, The Republic of (MD)

  Europe/Chisinau

=head3 Monaco (MC)

  Europe/Monaco

=head3 Mongolia (MN)

  Asia/Ulaanbaatar - most of Mongolia
  Asia/Hovd - Bayan-Olgii, Hovd, Uvs

=head3 Montenegro (ME)

  Europe/Podgorica

=head3 Montserrat (MS)

  America/Montserrat

=head3 Morocco (MA)

  Africa/Casablanca

=head3 Mozambique (MZ)

  Africa/Maputo

=head3 Myanmar (MM)

  Asia/Yangon

=head3 Namibia (NA)

  Africa/Windhoek

=head3 Nauru (NR)

  Pacific/Nauru

=head3 Nepal (NP)

  Asia/Kathmandu

=head3 Netherlands (Kingdom of the) (NL)

  Europe/Amsterdam

=head3 New Caledonia (NC)

  Pacific/Noumea

=head3 New Zealand (NZ)

  Pacific/Auckland - most of New Zealand
  Pacific/Chatham - Chatham Islands

=head3 Nicaragua (NI)

  America/Managua

=head3 Niger (NE)

  Africa/Niamey

=head3 Nigeria (NG)

  Africa/Lagos

=head3 Niue (NU)

  Pacific/Niue

=head3 Norfolk Island (NF)

  Pacific/Norfolk

=head3 North Macedonia (MK)

  Europe/Skopje

=head3 Northern Mariana Islands (MP)

  Pacific/Saipan

=head3 Norway (NO)

  Europe/Oslo

=head3 Oman (OM)

  Asia/Muscat

=head3 Pakistan (PK)

  Asia/Karachi

=head3 Palau (PW)

  Pacific/Palau

=head3 Palestine, State of (PS)

  Asia/Gaza - Gaza Strip
  Asia/Hebron - West Bank

=head3 Panama (PA)

  America/Panama

=head3 Papua New Guinea (PG)

  Pacific/Port_Moresby - most of Papua New Guinea
  Pacific/Bougainville - Bougainville

=head3 Paraguay (PY)

  America/Asuncion

=head3 Peru (PE)

  America/Lima

=head3 Philippines (PH)

  Asia/Manila

=head3 Pitcairn (PN)

  Pacific/Pitcairn

=head3 Poland (PL)

  Europe/Warsaw

=head3 Portugal (PT)

  Europe/Lisbon - Portugal (mainland)
  Atlantic/Madeira - Madeira Islands
  Atlantic/Azores - Azores

=head3 Puerto Rico (PR)

  America/Puerto_Rico

=head3 Qatar (QA)

  Asia/Qatar

=head3 Reunion (RE)

  Indian/Reunion

=head3 Romania (RO)

  Europe/Bucharest

=head3 Russian Federation (RU)

  Europe/Kaliningrad - MSK-01 - Kaliningrad
  Europe/Moscow - MSK+00 - Moscow area
  Europe/Kirov - MSK+00 - Kirov
  Europe/Volgograd - MSK+00 - Volgograd
  Europe/Astrakhan - MSK+01 - Astrakhan
  Europe/Saratov - MSK+01 - Saratov
  Europe/Ulyanovsk - MSK+01 - Ulyanovsk
  Europe/Samara - MSK+01 - Samara, Udmurtia
  Asia/Yekaterinburg - MSK+02 - Urals
  Asia/Omsk - MSK+03 - Omsk
  Asia/Novosibirsk - MSK+04 - Novosibirsk
  Asia/Barnaul - MSK+04 - Altai
  Asia/Tomsk - MSK+04 - Tomsk
  Asia/Novokuznetsk - MSK+04 - Kemerovo
  Asia/Krasnoyarsk - MSK+04 - Krasnoyarsk area
  Asia/Irkutsk - MSK+05 - Irkutsk, Buryatia
  Asia/Chita - MSK+06 - Zabaykalsky
  Asia/Yakutsk - MSK+06 - Lena River
  Asia/Khandyga - MSK+06 - Tomponsky, Ust-Maysky
  Asia/Vladivostok - MSK+07 - Amur River
  Asia/Ust-Nera - MSK+07 - Oymyakonsky
  Asia/Magadan - MSK+08 - Magadan
  Asia/Sakhalin - MSK+08 - Sakhalin Island
  Asia/Srednekolymsk - MSK+08 - Sakha (E), N Kuril Is
  Asia/Kamchatka - MSK+09 - Kamchatka
  Asia/Anadyr - MSK+09 - Bering Sea

=head3 Rwanda (RW)

  Africa/Kigali

=head3 Saint Barthelemy (BL)

  America/St_Barthelemy

=head3 Saint Helena, Ascension and Tristan da Cunha (SH)

  Atlantic/St_Helena

=head3 Saint Kitts and Nevis (KN)

  America/St_Kitts

=head3 Saint Lucia (LC)

  America/St_Lucia

=head3 Saint Martin (French part) (MF)

  America/Marigot

=head3 Saint Pierre and Miquelon (PM)

  America/Miquelon

=head3 Saint Vincent and the Grenadines (VC)

  America/St_Vincent

=head3 Samoa (WS)

  Pacific/Apia

=head3 San Marino (SM)

  Europe/San_Marino

=head3 Sao Tome and Principe (ST)

  Africa/Sao_Tome

=head3 Saudi Arabia (SA)

  Asia/Riyadh

=head3 Senegal (SN)

  Africa/Dakar

=head3 Serbia (RS)

  Europe/Belgrade

=head3 Seychelles (SC)

  Indian/Mahe

=head3 Sierra Leone (SL)

  Africa/Freetown

=head3 Singapore (SG)

  Asia/Singapore

=head3 Sint Maarten (Dutch part) (SX)

  America/Lower_Princes

=head3 Slovakia (SK)

  Europe/Bratislava

=head3 Slovenia (SI)

  Europe/Ljubljana

=head3 Solomon Islands (SB)

  Pacific/Guadalcanal

=head3 Somalia (SO)

  Africa/Mogadishu

=head3 South Africa (ZA)

  Africa/Johannesburg

=head3 South Georgia and the South Sandwich Islands (GS)

  Atlantic/South_Georgia

=head3 South Sudan (SS)

  Africa/Juba

=head3 Spain (ES)

  Europe/Madrid - Spain (mainland)
  Africa/Ceuta - Ceuta, Melilla
  Atlantic/Canary - Canary Islands

=head3 Sri Lanka (LK)

  Asia/Colombo

=head3 Sudan (SD)

  Africa/Khartoum

=head3 Suriname (SR)

  America/Paramaribo

=head3 Svalbard and Jan Mayen (SJ)

  Arctic/Longyearbyen

=head3 Sweden (SE)

  Europe/Stockholm

=head3 Switzerland (CH)

  Europe/Zurich

=head3 Syrian Arab Republic (SY)

  Asia/Damascus

=head3 Taiwan (Province of China) (TW)

  Asia/Taipei

=head3 Tajikistan (TJ)

  Asia/Dushanbe

=head3 Tanzania, the United Republic of (TZ)

  Africa/Dar_es_Salaam

=head3 Thailand (TH)

  Asia/Bangkok

=head3 Timor-Leste (TL)

  Asia/Dili

=head3 Togo (TG)

  Africa/Lome

=head3 Tokelau (TK)

  Pacific/Fakaofo

=head3 Tonga (TO)

  Pacific/Tongatapu

=head3 Trinidad and Tobago (TT)

  America/Port_of_Spain

=head3 Tunisia (TN)

  Africa/Tunis

=head3 Turkiye (TR)

  Europe/Istanbul

=head3 Turkmenistan (TM)

  Asia/Ashgabat

=head3 Turks and Caicos Islands (TC)

  America/Grand_Turk

=head3 Tuvalu (TV)

  Pacific/Funafuti

=head3 Uganda (UG)

  Africa/Kampala

=head3 Ukraine (UA)

  Europe/Simferopol - Crimea
  Europe/Kyiv - most of Ukraine

=head3 United Arab Emirates (AE)

  Asia/Dubai

=head3 United Kingdom of Great Britain and Northern Ireland (GB)

  Europe/London

=head3 United States Minor Outlying Islands (UM)

  Pacific/Midway - Midway Islands
  Pacific/Wake - Wake Island

=head3 United States of America (US)

  America/New_York - Eastern (most areas)
  America/Detroit - Eastern - MI (most areas)
  America/Kentucky/Louisville - Eastern - KY (Louisville area)
  America/Kentucky/Monticello - Eastern - KY (Wayne)
  America/Indiana/Indianapolis - Eastern - IN (most areas)
  America/Indiana/Vincennes - Eastern - IN (Da, Du, K, Mn)
  America/Indiana/Winamac - Eastern - IN (Pulaski)
  America/Indiana/Marengo - Eastern - IN (Crawford)
  America/Indiana/Petersburg - Eastern - IN (Pike)
  America/Indiana/Vevay - Eastern - IN (Switzerland)
  America/Chicago - Central (most areas)
  America/Indiana/Tell_City - Central - IN (Perry)
  America/Indiana/Knox - Central - IN (Starke)
  America/Menominee - Central - MI (Wisconsin border)
  America/North_Dakota/Center - Central - ND (Oliver)
  America/North_Dakota/New_Salem - Central - ND (Morton rural)
  America/North_Dakota/Beulah - Central - ND (Mercer)
  America/Denver - Mountain (most areas)
  America/Boise - Mountain - ID (south), OR (east)
  America/Phoenix - MST - AZ (except Navajo)
  America/Los_Angeles - Pacific
  America/Anchorage - Alaska (most areas)
  America/Juneau - Alaska - Juneau area
  America/Sitka - Alaska - Sitka area
  America/Metlakatla - Alaska - Annette Island
  America/Yakutat - Alaska - Yakutat
  America/Nome - Alaska (west)
  America/Adak - Alaska - western Aleutians
  Pacific/Honolulu - Hawaii

=head3 Uruguay (UY)

  America/Montevideo

=head3 Uzbekistan (UZ)

  Asia/Samarkand - Uzbekistan (west)
  Asia/Tashkent - Uzbekistan (east)

=head3 Vanuatu (VU)

  Pacific/Efate

=head3 Venezuela (Bolivarian Republic of) (VE)

  America/Caracas

=head3 Viet Nam (VN)

  Asia/Ho_Chi_Minh

=head3 Virgin Islands (British) (VG)

  America/Tortola

=head3 Virgin Islands (U.S.) (VI)

  America/St_Thomas

=head3 Wallis and Futuna (WF)

  Pacific/Wallis

=head3 Western Sahara (EH)

  Africa/El_Aaiun

=head3 Yemen (YE)

  Asia/Aden

=head3 Zambia (ZM)

  Africa/Lusaka

=head3 Zimbabwe (ZW)

  Africa/Harare

=head2 Linked Zones

A linked zone is an alias from one name to another.

  AKST9AKDT => America/Anchorage
  Africa/Accra => Africa/Abidjan
  Africa/Addis_Ababa => Africa/Nairobi
  Africa/Asmara => Africa/Nairobi
  Africa/Asmera => Africa/Nairobi
  Africa/Bamako => Africa/Abidjan
  Africa/Bangui => Africa/Lagos
  Africa/Banjul => Africa/Abidjan
  Africa/Blantyre => Africa/Maputo
  Africa/Brazzaville => Africa/Lagos
  Africa/Bujumbura => Africa/Maputo
  Africa/Conakry => Africa/Abidjan
  Africa/Dakar => Africa/Abidjan
  Africa/Dar_es_Salaam => Africa/Nairobi
  Africa/Djibouti => Africa/Nairobi
  Africa/Douala => Africa/Lagos
  Africa/Freetown => Africa/Abidjan
  Africa/Gaborone => Africa/Maputo
  Africa/Harare => Africa/Maputo
  Africa/Kampala => Africa/Nairobi
  Africa/Kigali => Africa/Maputo
  Africa/Kinshasa => Africa/Lagos
  Africa/Libreville => Africa/Lagos
  Africa/Lome => Africa/Abidjan
  Africa/Luanda => Africa/Lagos
  Africa/Lubumbashi => Africa/Maputo
  Africa/Lusaka => Africa/Maputo
  Africa/Malabo => Africa/Lagos
  Africa/Maseru => Africa/Johannesburg
  Africa/Mbabane => Africa/Johannesburg
  Africa/Mogadishu => Africa/Nairobi
  Africa/Niamey => Africa/Lagos
  Africa/Nouakchott => Africa/Abidjan
  Africa/Ouagadougou => Africa/Abidjan
  Africa/Porto-Novo => Africa/Lagos
  Africa/Timbuktu => Africa/Abidjan
  America/Anguilla => America/Puerto_Rico
  America/Antigua => America/Puerto_Rico
  America/Argentina/ComodRivadavia => America/Argentina/Catamarca
  America/Aruba => America/Puerto_Rico
  America/Atikokan => America/Panama
  America/Atka => America/Adak
  America/Blanc-Sablon => America/Puerto_Rico
  America/Buenos_Aires => America/Argentina/Buenos_Aires
  America/Catamarca => America/Argentina/Catamarca
  America/Cayman => America/Panama
  America/Coral_Harbour => America/Panama
  America/Cordoba => America/Argentina/Cordoba
  America/Creston => America/Phoenix
  America/Curacao => America/Puerto_Rico
  America/Dominica => America/Puerto_Rico
  America/Ensenada => America/Tijuana
  America/Fort_Wayne => America/Indiana/Indianapolis
  America/Godthab => America/Nuuk
  America/Grenada => America/Puerto_Rico
  America/Guadeloupe => America/Puerto_Rico
  America/Indianapolis => America/Indiana/Indianapolis
  America/Jujuy => America/Argentina/Jujuy
  America/Knox_IN => America/Indiana/Knox
  America/Kralendijk => America/Puerto_Rico
  America/Louisville => America/Kentucky/Louisville
  America/Lower_Princes => America/Puerto_Rico
  America/Marigot => America/Puerto_Rico
  America/Mendoza => America/Argentina/Mendoza
  America/Montreal => America/Toronto
  America/Montserrat => America/Puerto_Rico
  America/Nassau => America/Toronto
  America/Nipigon => America/Toronto
  America/Pangnirtung => America/Iqaluit
  America/Port_of_Spain => America/Puerto_Rico
  America/Porto_Acre => America/Rio_Branco
  America/Rainy_River => America/Winnipeg
  America/Rosario => America/Argentina/Cordoba
  America/Santa_Isabel => America/Tijuana
  America/Shiprock => America/Denver
  America/St_Barthelemy => America/Puerto_Rico
  America/St_Kitts => America/Puerto_Rico
  America/St_Lucia => America/Puerto_Rico
  America/St_Thomas => America/Puerto_Rico
  America/St_Vincent => America/Puerto_Rico
  America/Thunder_Bay => America/Toronto
  America/Tortola => America/Puerto_Rico
  America/Virgin => America/Puerto_Rico
  America/Yellowknife => America/Edmonton
  Antarctica/DumontDUrville => Pacific/Port_Moresby
  Antarctica/McMurdo => Pacific/Auckland
  Antarctica/South_Pole => Pacific/Auckland
  Antarctica/Syowa => Asia/Riyadh
  Arctic/Longyearbyen => Europe/Berlin
  Asia/Aden => Asia/Riyadh
  Asia/Ashkhabad => Asia/Ashgabat
  Asia/Bahrain => Asia/Qatar
  Asia/Brunei => Asia/Kuching
  Asia/Calcutta => Asia/Kolkata
  Asia/Choibalsan => Asia/Ulaanbaatar
  Asia/Chongqing => Asia/Shanghai
  Asia/Chungking => Asia/Shanghai
  Asia/Dacca => Asia/Dhaka
  Asia/Harbin => Asia/Shanghai
  Asia/Istanbul => Europe/Istanbul
  Asia/Kashgar => Asia/Urumqi
  Asia/Katmandu => Asia/Kathmandu
  Asia/Kuala_Lumpur => Asia/Singapore
  Asia/Kuwait => Asia/Riyadh
  Asia/Macao => Asia/Macau
  Asia/Muscat => Asia/Dubai
  Asia/Phnom_Penh => Asia/Bangkok
  Asia/Rangoon => Asia/Yangon
  Asia/Saigon => Asia/Ho_Chi_Minh
  Asia/Tel_Aviv => Asia/Jerusalem
  Asia/Thimbu => Asia/Thimphu
  Asia/Ujung_Pandang => Asia/Makassar
  Asia/Ulan_Bator => Asia/Ulaanbaatar
  Asia/Vientiane => Asia/Bangkok
  Atlantic/Faeroe => Atlantic/Faroe
  Atlantic/Jan_Mayen => Europe/Berlin
  Atlantic/Reykjavik => Africa/Abidjan
  Atlantic/St_Helena => Africa/Abidjan
  Australia/ACT => Australia/Sydney
  Australia/Canberra => Australia/Sydney
  Australia/Currie => Australia/Hobart
  Australia/LHI => Australia/Lord_Howe
  Australia/NSW => Australia/Sydney
  Australia/North => Australia/Darwin
  Australia/Queensland => Australia/Brisbane
  Australia/South => Australia/Adelaide
  Australia/Tasmania => Australia/Hobart
  Australia/Victoria => Australia/Melbourne
  Australia/West => Australia/Perth
  Australia/Yancowinna => Australia/Broken_Hill
  Brazil/Acre => America/Rio_Branco
  Brazil/DeNoronha => America/Noronha
  Brazil/East => America/Sao_Paulo
  Brazil/West => America/Manaus
  CET => Europe/Brussels
  CST6CDT => America/Chicago
  Canada/Atlantic => America/Halifax
  Canada/Central => America/Winnipeg
  Canada/Eastern => America/Toronto
  Canada/Mountain => America/Edmonton
  Canada/Newfoundland => America/St_Johns
  Canada/Pacific => America/Vancouver
  Canada/Saskatchewan => America/Regina
  Canada/Yukon => America/Whitehorse
  Chile/Continental => America/Santiago
  Chile/EasterIsland => Pacific/Easter
  Cuba => America/Havana
  EET => Europe/Athens
  EST => America/Panama
  EST5EDT => America/New_York
  Egypt => Africa/Cairo
  Eire => Europe/Dublin
  Etc/GMT => UTC
  Etc/GMT+0 => UTC
  Etc/GMT-0 => UTC
  Etc/GMT0 => UTC
  Etc/Greenwich => UTC
  Etc/UCT => UTC
  Etc/UTC => UTC
  Etc/Universal => UTC
  Etc/Zulu => UTC
  Europe/Amsterdam => Europe/Brussels
  Europe/Belfast => Europe/London
  Europe/Bratislava => Europe/Prague
  Europe/Busingen => Europe/Zurich
  Europe/Copenhagen => Europe/Berlin
  Europe/Guernsey => Europe/London
  Europe/Isle_of_Man => Europe/London
  Europe/Jersey => Europe/London
  Europe/Kiev => Europe/Kyiv
  Europe/Ljubljana => Europe/Belgrade
  Europe/Luxembourg => Europe/Brussels
  Europe/Mariehamn => Europe/Helsinki
  Europe/Monaco => Europe/Paris
  Europe/Nicosia => Asia/Nicosia
  Europe/Oslo => Europe/Berlin
  Europe/Podgorica => Europe/Belgrade
  Europe/San_Marino => Europe/Rome
  Europe/Sarajevo => Europe/Belgrade
  Europe/Skopje => Europe/Belgrade
  Europe/Stockholm => Europe/Berlin
  Europe/Tiraspol => Europe/Chisinau
  Europe/Uzhgorod => Europe/Kyiv
  Europe/Vaduz => Europe/Zurich
  Europe/Vatican => Europe/Rome
  Europe/Zagreb => Europe/Belgrade
  Europe/Zaporozhye => Europe/Kyiv
  GB => Europe/London
  GB-Eire => Europe/London
  GMT => UTC
  GMT+0 => UTC
  GMT-0 => UTC
  GMT0 => UTC
  Greenwich => UTC
  HST => Pacific/Honolulu
  Hongkong => Asia/Hong_Kong
  Iceland => Africa/Abidjan
  Indian/Antananarivo => Africa/Nairobi
  Indian/Christmas => Asia/Bangkok
  Indian/Cocos => Asia/Yangon
  Indian/Comoro => Africa/Nairobi
  Indian/Kerguelen => Indian/Maldives
  Indian/Mahe => Asia/Dubai
  Indian/Mayotte => Africa/Nairobi
  Indian/Reunion => Asia/Dubai
  Iran => Asia/Tehran
  Israel => Asia/Jerusalem
  JST-9 => Asia/Tokyo
  Jamaica => America/Jamaica
  Japan => Asia/Tokyo
  Kwajalein => Pacific/Kwajalein
  Libya => Africa/Tripoli
  MET => Europe/Brussels
  MST => America/Phoenix
  MST7MDT => America/Denver
  Mexico/BajaNorte => America/Tijuana
  Mexico/BajaSur => America/Mazatlan
  Mexico/General => America/Mexico_City
  NZ => Pacific/Auckland
  NZ-CHAT => Pacific/Chatham
  Navajo => America/Denver
  PRC => Asia/Shanghai
  PST8PDT => America/Los_Angeles
  Pacific/Chuuk => Pacific/Port_Moresby
  Pacific/Enderbury => Pacific/Kanton
  Pacific/Funafuti => Pacific/Tarawa
  Pacific/Johnston => Pacific/Honolulu
  Pacific/Majuro => Pacific/Tarawa
  Pacific/Midway => Pacific/Pago_Pago
  Pacific/Pohnpei => Pacific/Guadalcanal
  Pacific/Ponape => Pacific/Guadalcanal
  Pacific/Saipan => Pacific/Guam
  Pacific/Samoa => Pacific/Pago_Pago
  Pacific/Truk => Pacific/Port_Moresby
  Pacific/Wake => Pacific/Tarawa
  Pacific/Wallis => Pacific/Tarawa
  Pacific/Yap => Pacific/Port_Moresby
  Poland => Europe/Warsaw
  Portugal => Europe/Lisbon
  ROC => Asia/Taipei
  ROK => Asia/Seoul
  Singapore => Asia/Singapore
  Turkey => Europe/Istanbul
  UCT => UTC
  US/Alaska => America/Anchorage
  US/Aleutian => America/Adak
  US/Arizona => America/Phoenix
  US/Central => America/Chicago
  US/East-Indiana => America/Indiana/Indianapolis
  US/Eastern => America/New_York
  US/Hawaii => Pacific/Honolulu
  US/Indiana-Starke => America/Indiana/Knox
  US/Michigan => America/Detroit
  US/Mountain => America/Denver
  US/Pacific => America/Los_Angeles
  US/Samoa => Pacific/Pago_Pago
  Universal => UTC
  W-SU => Europe/Moscow
  WET => Europe/Lisbon
  Zulu => UTC

=cut
